internalversion

package
v1.1.8-dev6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2023 License: Apache-2.0, BSD-3-Clause Imports: 7 Imported by: 0

Documentation

Overview

This package has the automatically generated typed clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AWSMachineClassExpansion added in v1.0.5

type AWSMachineClassExpansion interface{}

type AWSMachineClassInterface added in v1.0.5

type AWSMachineClassInterface interface {
	Create(*machine.AWSMachineClass) (*machine.AWSMachineClass, error)
	Update(*machine.AWSMachineClass) (*machine.AWSMachineClass, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.AWSMachineClass, error)
	List(opts v1.ListOptions) (*machine.AWSMachineClassList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.AWSMachineClass, err error)
	AWSMachineClassExpansion
}

AWSMachineClassInterface has methods to work with AWSMachineClass resources.

type AWSMachineClassesGetter added in v1.0.5

type AWSMachineClassesGetter interface {
	AWSMachineClasses(namespace string) AWSMachineClassInterface
}

AWSMachineClassesGetter has a method to return a AWSMachineClassInterface. A group's client should implement this interface.

type AlicloudMachineClassExpansion added in v1.0.5

type AlicloudMachineClassExpansion interface{}

type AlicloudMachineClassInterface added in v1.0.5

type AlicloudMachineClassInterface interface {
	Create(*machine.AlicloudMachineClass) (*machine.AlicloudMachineClass, error)
	Update(*machine.AlicloudMachineClass) (*machine.AlicloudMachineClass, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.AlicloudMachineClass, error)
	List(opts v1.ListOptions) (*machine.AlicloudMachineClassList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.AlicloudMachineClass, err error)
	AlicloudMachineClassExpansion
}

AlicloudMachineClassInterface has methods to work with AlicloudMachineClass resources.

type AlicloudMachineClassesGetter added in v1.0.5

type AlicloudMachineClassesGetter interface {
	AlicloudMachineClasses(namespace string) AlicloudMachineClassInterface
}

AlicloudMachineClassesGetter has a method to return a AlicloudMachineClassInterface. A group's client should implement this interface.

type AzureMachineClassExpansion added in v1.0.5

type AzureMachineClassExpansion interface{}

type AzureMachineClassInterface added in v1.0.5

type AzureMachineClassInterface interface {
	Create(*machine.AzureMachineClass) (*machine.AzureMachineClass, error)
	Update(*machine.AzureMachineClass) (*machine.AzureMachineClass, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.AzureMachineClass, error)
	List(opts v1.ListOptions) (*machine.AzureMachineClassList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.AzureMachineClass, err error)
	AzureMachineClassExpansion
}

AzureMachineClassInterface has methods to work with AzureMachineClass resources.

type AzureMachineClassesGetter added in v1.0.5

type AzureMachineClassesGetter interface {
	AzureMachineClasses(namespace string) AzureMachineClassInterface
}

AzureMachineClassesGetter has a method to return a AzureMachineClassInterface. A group's client should implement this interface.

type GCPMachineClassExpansion added in v1.0.5

type GCPMachineClassExpansion interface{}

type GCPMachineClassInterface added in v1.0.5

type GCPMachineClassInterface interface {
	Create(*machine.GCPMachineClass) (*machine.GCPMachineClass, error)
	Update(*machine.GCPMachineClass) (*machine.GCPMachineClass, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.GCPMachineClass, error)
	List(opts v1.ListOptions) (*machine.GCPMachineClassList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.GCPMachineClass, err error)
	GCPMachineClassExpansion
}

GCPMachineClassInterface has methods to work with GCPMachineClass resources.

type GCPMachineClassesGetter added in v1.0.5

type GCPMachineClassesGetter interface {
	GCPMachineClasses(namespace string) GCPMachineClassInterface
}

GCPMachineClassesGetter has a method to return a GCPMachineClassInterface. A group's client should implement this interface.

type MachineClassExpansion

type MachineClassExpansion interface{}

type MachineClassInterface

type MachineClassInterface interface {
	Create(*machine.MachineClass) (*machine.MachineClass, error)
	Update(*machine.MachineClass) (*machine.MachineClass, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.MachineClass, error)
	List(opts v1.ListOptions) (*machine.MachineClassList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.MachineClass, err error)
	MachineClassExpansion
}

MachineClassInterface has methods to work with MachineClass resources.

type MachineClassesGetter

type MachineClassesGetter interface {
	MachineClasses(namespace string) MachineClassInterface
}

MachineClassesGetter has a method to return a MachineClassInterface. A group's client should implement this interface.

type MachineClient

type MachineClient struct {
	// contains filtered or unexported fields
}

MachineClient is used to interact with features provided by the machine.sapcloud.io group.

func New

New creates a new MachineClient for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*MachineClient, error)

NewForConfig creates a new MachineClient for the given config.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *MachineClient

NewForConfigOrDie creates a new MachineClient for the given config and panics if there is an error in the config.

func (*MachineClient) AWSMachineClasses added in v1.0.5

func (c *MachineClient) AWSMachineClasses(namespace string) AWSMachineClassInterface

func (*MachineClient) AlicloudMachineClasses added in v1.0.5

func (c *MachineClient) AlicloudMachineClasses(namespace string) AlicloudMachineClassInterface

func (*MachineClient) AzureMachineClasses added in v1.0.5

func (c *MachineClient) AzureMachineClasses(namespace string) AzureMachineClassInterface

func (*MachineClient) GCPMachineClasses added in v1.0.5

func (c *MachineClient) GCPMachineClasses(namespace string) GCPMachineClassInterface

func (*MachineClient) MachineClasses

func (c *MachineClient) MachineClasses(namespace string) MachineClassInterface

func (*MachineClient) MachineDeployments

func (c *MachineClient) MachineDeployments(namespace string) MachineDeploymentInterface

func (*MachineClient) MachineSets

func (c *MachineClient) MachineSets(namespace string) MachineSetInterface

func (*MachineClient) MachineTemplates

func (c *MachineClient) MachineTemplates(namespace string) MachineTemplateInterface

func (*MachineClient) Machines

func (c *MachineClient) Machines(namespace string) MachineInterface

func (*MachineClient) OpenStackMachineClasses added in v1.0.5

func (c *MachineClient) OpenStackMachineClasses(namespace string) OpenStackMachineClassInterface

func (*MachineClient) PacketMachineClasses added in v1.0.5

func (c *MachineClient) PacketMachineClasses(namespace string) PacketMachineClassInterface

func (*MachineClient) RESTClient

func (c *MachineClient) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

type MachineDeploymentExpansion

type MachineDeploymentExpansion interface{}

type MachineDeploymentInterface

type MachineDeploymentInterface interface {
	Create(*machine.MachineDeployment) (*machine.MachineDeployment, error)
	Update(*machine.MachineDeployment) (*machine.MachineDeployment, error)
	UpdateStatus(*machine.MachineDeployment) (*machine.MachineDeployment, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.MachineDeployment, error)
	List(opts v1.ListOptions) (*machine.MachineDeploymentList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.MachineDeployment, err error)
	GetScale(machineDeploymentName string, options v1.GetOptions) (*machine.Scale, error)
	UpdateScale(machineDeploymentName string, scale *machine.Scale) (*machine.Scale, error)

	MachineDeploymentExpansion
}

MachineDeploymentInterface has methods to work with MachineDeployment resources.

type MachineDeploymentsGetter

type MachineDeploymentsGetter interface {
	MachineDeployments(namespace string) MachineDeploymentInterface
}

MachineDeploymentsGetter has a method to return a MachineDeploymentInterface. A group's client should implement this interface.

type MachineExpansion

type MachineExpansion interface{}

type MachineSetExpansion

type MachineSetExpansion interface{}

type MachineSetInterface

type MachineSetInterface interface {
	Create(*machine.MachineSet) (*machine.MachineSet, error)
	Update(*machine.MachineSet) (*machine.MachineSet, error)
	UpdateStatus(*machine.MachineSet) (*machine.MachineSet, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.MachineSet, error)
	List(opts v1.ListOptions) (*machine.MachineSetList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.MachineSet, err error)
	MachineSetExpansion
}

MachineSetInterface has methods to work with MachineSet resources.

type MachineSetsGetter

type MachineSetsGetter interface {
	MachineSets(namespace string) MachineSetInterface
}

MachineSetsGetter has a method to return a MachineSetInterface. A group's client should implement this interface.

type MachineTemplateExpansion

type MachineTemplateExpansion interface{}

type MachineTemplateInterface

type MachineTemplateInterface interface {
	Create(*machine.MachineTemplate) (*machine.MachineTemplate, error)
	Update(*machine.MachineTemplate) (*machine.MachineTemplate, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.MachineTemplate, error)
	List(opts v1.ListOptions) (*machine.MachineTemplateList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.MachineTemplate, err error)
	MachineTemplateExpansion
}

MachineTemplateInterface has methods to work with MachineTemplate resources.

type MachineTemplatesGetter

type MachineTemplatesGetter interface {
	MachineTemplates(namespace string) MachineTemplateInterface
}

MachineTemplatesGetter has a method to return a MachineTemplateInterface. A group's client should implement this interface.

type MachinesGetter

type MachinesGetter interface {
	Machines(namespace string) MachineInterface
}

MachinesGetter has a method to return a MachineInterface. A group's client should implement this interface.

type OpenStackMachineClassExpansion added in v1.0.5

type OpenStackMachineClassExpansion interface{}

type OpenStackMachineClassInterface added in v1.0.5

type OpenStackMachineClassInterface interface {
	Create(*machine.OpenStackMachineClass) (*machine.OpenStackMachineClass, error)
	Update(*machine.OpenStackMachineClass) (*machine.OpenStackMachineClass, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.OpenStackMachineClass, error)
	List(opts v1.ListOptions) (*machine.OpenStackMachineClassList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.OpenStackMachineClass, err error)
	OpenStackMachineClassExpansion
}

OpenStackMachineClassInterface has methods to work with OpenStackMachineClass resources.

type OpenStackMachineClassesGetter added in v1.0.5

type OpenStackMachineClassesGetter interface {
	OpenStackMachineClasses(namespace string) OpenStackMachineClassInterface
}

OpenStackMachineClassesGetter has a method to return a OpenStackMachineClassInterface. A group's client should implement this interface.

type PacketMachineClassExpansion added in v1.0.5

type PacketMachineClassExpansion interface{}

type PacketMachineClassInterface added in v1.0.5

type PacketMachineClassInterface interface {
	Create(*machine.PacketMachineClass) (*machine.PacketMachineClass, error)
	Update(*machine.PacketMachineClass) (*machine.PacketMachineClass, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*machine.PacketMachineClass, error)
	List(opts v1.ListOptions) (*machine.PacketMachineClassList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *machine.PacketMachineClass, err error)
	PacketMachineClassExpansion
}

PacketMachineClassInterface has methods to work with PacketMachineClass resources.

type PacketMachineClassesGetter added in v1.0.5

type PacketMachineClassesGetter interface {
	PacketMachineClasses(namespace string) PacketMachineClassInterface
}

PacketMachineClassesGetter has a method to return a PacketMachineClassInterface. A group's client should implement this interface.

Directories

Path Synopsis
Package fake has the automatically generated clients.
Package fake has the automatically generated clients.

Jump to